==> syncai-0.6.0.tar.gz: syncai-0.6.0/README.md <==
<p align="center">
  <img align="center" width="120" src="https://github.com/user-attachments/assets/97397eee-2e82-4eb5-a4e3-7277db2e7d04" />

  <h1 align="center">HackerGpt</h1>
  <h3 align="center"></h3>
</p>


<p align="center">

<a href="https://pypi.org/project/SyncAi/">
    <img src="https://img.shields.io/pypi/v/SyncAi?color=red&logo=pypi&logoColor=red">
  </a>

  <a href="https://t.me/Pycodz">
    <img src="https://img.shields.io/badge/Telegram-Channel-blue.svg?logo=telegram">
  </a>
  
  <a href="https://t.me/DevZ44d" target="_blank">
    <img alt="Telegram Owner" src="https://img.shields.io/badge/Telegram-Owner-red.svg?logo=telegram" />
  </a>
</p>

> **Notice:** API-KEY may be Expire so Contact Me For Get Free **[Telegram Chat](https://t.me/iasynx)** .

> **HackerGPT** is an advanced AI designed for cybersecurity professionals, `ethical hackers` , `MalWare`, and `penetration testers`. It assists in `vulnerability analysis`, `security script generation`, and `cybersecurity research`, `Backdoor implementation` . Unlike traditional AI models, HackerGPT provides unrestricted access, empowering you to explore the cyber world with greater flexibility and efficiency. 🚀
  
### Installation and Development 🚀

### Via `PyPi` ⚡️
```shell
# via PyPi
pip install SyncAi -U
```

### 🚀 Quick Start
```python
from SyncAi import HackerGpt
prompt = input("Type Your PromPt : ")
response = HackerGpt.chat(prompt)
print(response)
```
### Using in `Terminal` 🚀
```shell
syncai -[OPTIONS] "[PROMPT]"
```

### Usage 📚
```shell
Usage: syncai -[OPTIONS] "[PROMPT]"

Options
  -p, --prompt                    Start Chatting  .
  -img, --imager                  Generation images by prompt .
  -h, --help                      Show this message and exit .
  -v, --version                   Show Version Of Libarary .
```

### Via `Git` ( Recommended ) ⚡️

```shell
# via Git
git clone https://github.com/DevZ44d/HackerGpt.git

cd HackerGpt

python3 main.py
```
### 📦 Features
- Save Chats ( **[In My GitHub Repositories](https://github.com/DevZ44d/HackerGpt)** ) .
- Free API-Key .

### 💬 Help & Support .
- Follow updates via the **[Telegram Channel](https://t.me/Pycodz)**.
- For general questions and help, join our **[Telegram chat](https://t.me/PyChTz)**.

==> syncai-0.8.0.tar.gz: syncai-0.8.0/README.md <==
<p align="center">
  <img align="center" width="120" src="https://github.com/user-attachments/assets/97397eee-2e82-4eb5-a4e3-7277db2e7d04" />

  <h1 align="center">HackerGpt</h1>
  <h3 align="center"></h3>
</p>


<p align="center">

<a href="https://pypi.org/project/SyncAi/">
    <img src="https://img.shields.io/pypi/v/SyncAi?color=red&logo=pypi&logoColor=red">
  </a>

  <a href="https://t.me/Pycodz">
    <img src="https://img.shields.io/badge/Telegram-Channel-blue.svg?logo=telegram">
  </a>
  
  <a href="https://t.me/DevZ44d" target="_blank">
    <img alt="Telegram Owner" src="https://img.shields.io/badge/Telegram-Owner-red.svg?logo=telegram" />
  </a>
</p>

> **Notice:** API-KEY may be Expire so Contact Me For Get Free **[Telegram Chat](https://t.me/iasynx)** .

> **HackerGPT** is an advanced AI designed for cybersecurity professionals, `ethical hackers` , `MalWare`, and `penetration testers`. It assists in `vulnerability analysis`, `security script generation`, and `cybersecurity research`, `Backdoor implementation` . Unlike traditional AI models, HackerGPT provides unrestricted access, empowering you to explore the cyber world with greater flexibility and efficiency. 🚀
  
### Installation and Development 🚀

### Via `PyPi` ⚡️
```shell
# via PyPi
pip install SyncAi -U
```

### 🚀 Quick Start
```python
from SyncAi import HackerGpt
prompt = input("Type Your PromPt : ")
response = HackerGpt.chat(prompt)
print(response)
```
### Using in `Terminal` 🚀
```shell
syncai -[OPTIONS] "[PROMPT]"
```

### Usage 📚
```shell
Usage: syncai -[OPTIONS] "[PROMPT]"

Options
  -p, --prompt                    Start Chatting  .
  -img, --imager                  Generation images by prompt .
  -h, --help                      Show this message and exit .
  -v, --version                   Show Version Of Libarary .
```

### Via `Git` ( Recommended ) ⚡️

```shell
# via Git
git clone https://github.com/DevZ44d/HackerGpt.git

cd HackerGpt

python3 main.py
```
### 📦 Features
- **Save Chats** ( **[In My GitHub Repositories](https://github.com/DevZ44d/HackerGpt)** ) .
- Free **API-Key** .

### 💬 Help & Support .
- Follow updates via the **[Telegram Channel](https://t.me/Pycodz)**.
- For general questions and help, join our **[Telegram chat](https://t.me/PyChTz)**.
